==> freebsd-sys-8.2.tar.bz2: sys/fs/tmpfs/tmpfs_fifoops.c <==
/*	$NetBSD: tmpfs_fifoops.c,v 1.5 2005/12/11 12:24:29 christos Exp $	*/

/*-
 * Copyright (c) 2005 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Julio M. Merino Vidal, developed as part of Google's Summer of Code
 * 2005 program.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * tmpfs vnode interface for named pipes.
 */
#include <sys/cdefs.h>
 __FBSDID("$FreeBSD: src/sys/fs/tmpfs/tmpfs_fifoops.c,v 1.4.2.1.6.1 2010/12/21 17:09:25 kensmith Exp $");

#include <sys/param.h>
#include <sys/filedesc.h>
#include <sys/proc.h>
#include <sys/vnode.h>

#include <vm/vm.h>
#include <vm/vm_object.h>

#include <fs/tmpfs/tmpfs.h>
#include <fs/tmpfs/tmpfs_fifoops.h>
#include <fs/tmpfs/tmpfs_vnops.h>

/* --------------------------------------------------------------------- */

static int
tmpfs_fifo_kqfilter(struct vop_kqfilter_args *ap)
{
	struct vnode *vp;
	struct tmpfs_node *node;

	vp = ap->a_vp;
	node = VP_TO_TMPFS_NODE(vp);

	switch (ap->a_kn->kn_filter){
	case EVFILT_READ:
		node->tn_status |= TMPFS_NODE_ACCESSED;
		break;
	case EVFILT_WRITE:
		node->tn_status |= TMPFS_NODE_MODIFIED;
		break;
	}

	return fifo_specops.vop_kqfilter(ap);
}

/* --------------------------------------------------------------------- */

static int
tmpfs_fifo_close(struct vop_close_args *v)
{
	struct tmpfs_node *node;
	node = VP_TO_TMPFS_NODE(v->a_vp);
	node->tn_status |= TMPFS_NODE_ACCESSED;

	tmpfs_update(v->a_vp);
	return fifo_specops.vop_close(v);
}

/*
 * vnode operations vector used for fifos stored in a tmpfs file system.
 */
struct vop_vector tmpfs_fifoop_entries = {
	.vop_default =			&fifo_specops,
	.vop_close =			tmpfs_fifo_close,
	.vop_reclaim =			tmpfs_reclaim,
	.vop_access =			tmpfs_access,
	.vop_getattr =			tmpfs_getattr,
	.vop_setattr =			tmpfs_setattr,
	.vop_kqfilter =			tmpfs_fifo_kqfilter,
};

==> freebsd-sys-9.2_rc3.tar.bz2: sys/fs/tmpfs/tmpfs_fifoops.c <==
/*	$NetBSD: tmpfs_fifoops.c,v 1.5 2005/12/11 12:24:29 christos Exp $	*/

/*-
 * Copyright (c) 2005 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Julio M. Merino Vidal, developed as part of Google's Summer of Code
 * 2005 program.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * tmpfs vnode interface for named pipes.
 */
#include <sys/cdefs.h>
 __FBSDID("$FreeBSD: releng/9.2/sys/fs/tmpfs/tmpfs_fifoops.c 182739 2008-09-03 18:53:48Z delphij $");

#include <sys/param.h>
#include <sys/filedesc.h>
#include <sys/proc.h>
#include <sys/vnode.h>

#include <vm/vm.h>
#include <vm/vm_object.h>

#include <fs/tmpfs/tmpfs.h>
#include <fs/tmpfs/tmpfs_fifoops.h>
#include <fs/tmpfs/tmpfs_vnops.h>

/* --------------------------------------------------------------------- */

static int
tmpfs_fifo_kqfilter(struct vop_kqfilter_args *ap)
{
	struct vnode *vp;
	struct tmpfs_node *node;

	vp = ap->a_vp;
	node = VP_TO_TMPFS_NODE(vp);

	switch (ap->a_kn->kn_filter){
	case EVFILT_READ:
		node->tn_status |= TMPFS_NODE_ACCESSED;
		break;
	case EVFILT_WRITE:
		node->tn_status |= TMPFS_NODE_MODIFIED;
		break;
	}

	return fifo_specops.vop_kqfilter(ap);
}

/* --------------------------------------------------------------------- */

static int
tmpfs_fifo_close(struct vop_close_args *v)
{
	struct tmpfs_node *node;
	node = VP_TO_TMPFS_NODE(v->a_vp);
	node->tn_status |= TMPFS_NODE_ACCESSED;

	tmpfs_update(v->a_vp);
	return fifo_specops.vop_close(v);
}

/*
 * vnode operations vector used for fifos stored in a tmpfs file system.
 */
struct vop_vector tmpfs_fifoop_entries = {
	.vop_default =			&fifo_specops,
	.vop_close =			tmpfs_fifo_close,
	.vop_reclaim =			tmpfs_reclaim,
	.vop_access =			tmpfs_access,
	.vop_getattr =			tmpfs_getattr,
	.vop_setattr =			tmpfs_setattr,
	.vop_kqfilter =			tmpfs_fifo_kqfilter,
};
